@@ -248,7 +248,7 @@ class IotToKinesisStreamsProps:
         :summary: The properties for the IotToKinesisFirehoseToS3 Construct
         '''
         if isinstance(iot_topic_rule_props, dict):
-            iot_topic_rule_props = CfnTopicRuleProps(**iot_topic_rule_props)
+            iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
         if __debug__:
             type_hints = typing.get_type_hints(IotToKinesisStreamsProps.__init__)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
